==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Surface_mesh_topology/group__PkgSurfaceMeshTopologyClasses.js <==
var group__PkgSurfaceMeshTopologyClasses =
[
    [ "Curves_on_surface_topology", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a7fc50a348a8b3b265301a6821bcbaa24", null ],
      [ "Curves_on_surface_topology", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a5b7143b973ad40dff2fd5fc24c2ffcfd", null ],
      [ "are_freely_homotopic", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a85fc4a1f20c84073814251af6912539d", null ],
      [ "are_homotopic_with_fixed_endpoints", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a05dba41f3012ec7747aa215e2af2f152", null ],
      [ "compute_edge_width", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#ab3f9842e89ec2fa60efa90586ba8f75a", null ],
      [ "compute_face_width", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#afc5fc6cdd80c7fb053cb959e9c534cc1", null ],
      [ "compute_shortest_non_contractible_cycle", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#ab4a3ec02fe8bcfad6bb45a2b11046e95", null ],
      [ "compute_shortest_non_contractible_cycle_with_base_point", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a1b6fe01f021a71b8376bb1f502e9d069", null ],
      [ "is_contractible", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a816ad97901765d303ee5fa50fc8a0d0b", null ],
      [ "is_homotopic_to_simple_cycle", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a8d7c4cba2cf2cff542f5cd93117233db", null ],
      [ "set_verbose", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a54878d88b4dea6d3a51ff9a2ea112b1e", null ]
    ] ],
    [ "Unit_weight_functor", "structCGAL_1_1Surface__mesh__topology_1_1Unit__weight__functor.html", [
      [ "Weight_t", "structCGAL_1_1Surface__mesh__topology_1_1Unit__weight__functor.html#aecdff4376e9ca84e80dc9b4a45f76cee", null ]
    ] ],
    [ "Euclidean_length_weight_functor", "structCGAL_1_1Surface__mesh__topology_1_1Euclidean__length__weight__functor.html", [
      [ "Weight_t", "structCGAL_1_1Surface__mesh__topology_1_1Euclidean__length__weight__functor.html#a85debc09961a33890c354d9c653389cc", null ],
      [ "Euclidean_length_weight_functor", "structCGAL_1_1Surface__mesh__topology_1_1Euclidean__length__weight__functor.html#ab67719e46ed447d57b2f887d4e948e7b", null ]
    ] ],
    [ "Path_on_surface", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a5f6f8760175c123edcbae62fb7ce04e4", null ],
      [ "Path_on_surface", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#ad51f8aa548bc907327904fcea4f9ff96", null ],
      [ "can_be_pushed", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a3aae17ee1adefd962310e19994a8b620", null ],
      [ "can_be_pushed_by_index", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#acdd26daa275609bb5b34606dac122d7f", null ],
      [ "can_be_pushed_by_label", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a9dc8e934c952a9b3ac3578878d19093c", null ],
      [ "clear", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a9ba1154cfe4e58b35a0cacca4f90b0a9", null ],
      [ "extend_negative_turn", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a3b1629a7e6e46e0477166a18ae1d1e96", null ],
      [ "extend_positive_turn", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a1d84ab79576f8f41f5124c2b5fe7c55f", null ],
      [ "generate_random_closed_path", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a7b6cb5478efe630cee3142fbe233224e", null ],
      [ "generate_random_path", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a10d3e1b1563e882ad1bc58655dc8fee0", null ],
      [ "is_closed", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a16ead319d042e66c17faa0cd31b56152", null ],
      [ "is_empty", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#acda772afa7e2f2851974f1398ae04d00", null ],
      [ "is_simple", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a273bf6cf48f71931b6793248acf99ae0", null ],
      [ "length", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a7dc4d68b6bbc174b07398190edd855f9", null ],
      [ "operator+=", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a8603b059292cd75537d4717295962891", null ],
      [ "operator[]", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#abf8d11d33d4b366a72290f1b78c801be", null ],
      [ "push_back", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a7ab5d5739194b4c972aa74c49cb05543", null ],
      [ "push_back_by_index", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a3bf430e3e6fc0fd2d173b98cffcdb89d", null ],
      [ "push_back_by_index", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a0876bf4a6d720ec94be64f7f9d63c766", null ],
      [ "push_back_by_label", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#afad1f86d456ab700558a703bb9dff496", null ],
      [ "reverse", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#afe643c7a1a2f005277b30fbcc06bc710", null ]
    ] ],
    [ "Polygonal_schema_with_combinatorial_map", "classCGAL_1_1Surface__mesh__topology_1_1Polygonal__schema__with__combinatorial__map.html", null ],
    [ "Polygonal_schema_with_generalized_map", "classCGAL_1_1Surface__mesh__topology_1_1Polygonal__schema__with__generalized__map.html", null ],
    [ "Polygonal_schema_min_items", "structCGAL_1_1Surface__mesh__topology_1_1Polygonal__schema__min__items.html", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Surface_mesh_topology/group__PkgSurfaceMeshTopologyClasses.js <==
var group__PkgSurfaceMeshTopologyClasses =
[
    [ "CGAL::Surface_mesh_topology::Curves_on_surface_topology< Mesh >", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a7fc50a348a8b3b265301a6821bcbaa24", null ],
      [ "Curves_on_surface_topology", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a5b7143b973ad40dff2fd5fc24c2ffcfd", null ],
      [ "are_freely_homotopic", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a85fc4a1f20c84073814251af6912539d", null ],
      [ "are_homotopic_with_fixed_endpoints", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a05dba41f3012ec7747aa215e2af2f152", null ],
      [ "compute_edge_width", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a38561507c54e7a0c70b7d8cd00cd9713", null ],
      [ "compute_face_width", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#ab1e89845805ea2bfbdbeb6344aed8643", null ],
      [ "compute_shortest_non_contractible_cycle", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a8292fce8d2ea8e2f9657196626e6af82", null ],
      [ "compute_shortest_non_contractible_cycle_with_base_point", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a415f2d76b13fdb39d4e3f10c611ad412", null ],
      [ "is_contractible", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a816ad97901765d303ee5fa50fc8a0d0b", null ],
      [ "is_homotopic_to_simple_cycle", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a8d7c4cba2cf2cff542f5cd93117233db", null ],
      [ "set_verbose", "classCGAL_1_1Surface__mesh__topology_1_1Curves__on__surface__topology.html#a54878d88b4dea6d3a51ff9a2ea112b1e", null ]
    ] ],
    [ "CGAL::Surface_mesh_topology::Unit_weight_functor", "structCGAL_1_1Surface__mesh__topology_1_1Unit__weight__functor.html", [
      [ "Weight_t", "structCGAL_1_1Surface__mesh__topology_1_1Unit__weight__functor.html#aecdff4376e9ca84e80dc9b4a45f76cee", null ]
    ] ],
    [ "CGAL::Surface_mesh_topology::Euclidean_length_weight_functor< Mesh >", "structCGAL_1_1Surface__mesh__topology_1_1Euclidean__length__weight__functor.html", [
      [ "Weight_t", "structCGAL_1_1Surface__mesh__topology_1_1Euclidean__length__weight__functor.html#a85debc09961a33890c354d9c653389cc", null ],
      [ "Euclidean_length_weight_functor", "structCGAL_1_1Surface__mesh__topology_1_1Euclidean__length__weight__functor.html#ab67719e46ed447d57b2f887d4e948e7b", null ]
    ] ],
    [ "CGAL::Surface_mesh_topology::Path_on_surface< Mesh >", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a5f6f8760175c123edcbae62fb7ce04e4", null ],
      [ "Path_on_surface", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#ad51f8aa548bc907327904fcea4f9ff96", null ],
      [ "can_be_pushed", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a3aae17ee1adefd962310e19994a8b620", null ],
      [ "can_be_pushed_by_index", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#acdd26daa275609bb5b34606dac122d7f", null ],
      [ "can_be_pushed_by_label", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a9dc8e934c952a9b3ac3578878d19093c", null ],
      [ "clear", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a9ba1154cfe4e58b35a0cacca4f90b0a9", null ],
      [ "extend_negative_turn", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a3b1629a7e6e46e0477166a18ae1d1e96", null ],
      [ "extend_positive_turn", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a1d84ab79576f8f41f5124c2b5fe7c55f", null ],
      [ "generate_random_closed_path", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a7b6cb5478efe630cee3142fbe233224e", null ],
      [ "generate_random_path", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a10d3e1b1563e882ad1bc58655dc8fee0", null ],
      [ "is_closed", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a16ead319d042e66c17faa0cd31b56152", null ],
      [ "is_empty", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#acda772afa7e2f2851974f1398ae04d00", null ],
      [ "is_simple", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a273bf6cf48f71931b6793248acf99ae0", null ],
      [ "length", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a7dc4d68b6bbc174b07398190edd855f9", null ],
      [ "operator+=", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#ad3cc8980f80c3b17b66b7a8600810c5b", null ],
      [ "operator[]", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#abf8d11d33d4b366a72290f1b78c801be", null ],
      [ "push_back", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a7ab5d5739194b4c972aa74c49cb05543", null ],
      [ "push_back_by_index", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a0876bf4a6d720ec94be64f7f9d63c766", null ],
      [ "push_back_by_index", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#a3bf430e3e6fc0fd2d173b98cffcdb89d", null ],
      [ "push_back_by_label", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#afad1f86d456ab700558a703bb9dff496", null ],
      [ "reverse", "classCGAL_1_1Surface__mesh__topology_1_1Path__on__surface.html#afe643c7a1a2f005277b30fbcc06bc710", null ]
    ] ],
    [ "CGAL::Surface_mesh_topology::Polygonal_schema_with_combinatorial_map< Items, Alloc >", "classCGAL_1_1Surface__mesh__topology_1_1Polygonal__schema__with__combinatorial__map.html", null ],
    [ "CGAL::Surface_mesh_topology::Polygonal_schema_with_generalized_map< Items, Alloc >", "classCGAL_1_1Surface__mesh__topology_1_1Polygonal__schema__with__generalized__map.html", null ],
    [ "CGAL::Surface_mesh_topology::Polygonal_schema_min_items", "structCGAL_1_1Surface__mesh__topology_1_1Polygonal__schema__min__items.html", null ]
];
